@@ -1,5 +1,7 @@
 from .functions import *
 from moviepy.editor import *
+# sort the list
+import re
 def preprocess_for_ocr(image_path: str) -> np.ndarray:
     img = cv2.imread(image_path)
     gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
@@ -29,7 +31,10 @@ def preprocess_for_ocr(image_path: str) -> np.ndarray:
 
 def is_frame_analyzed(frame_file,video_text_data):
     for values in video_text_data:
-        frame = values.get("frame")
+        frame = values
+        if isinstance(values,dict):
+            frame = values.get("frame")
+        
         if frame_file == frame:
             return True
         
@@ -54,7 +59,11 @@ def analyze_video_text(video_path,output_dir,json_data,remove_phrases=None,video
                 cleaned_text = clean_text(raw_text)
                 text = determine_remove_text(cleaned_text,remove_phrases=json_data['remove_phrases'])
                 json_data['video_text'].append({"frame": frame_file, "text": text})
-    # Clean up (optional)
+    
+
+    json_data["video_text"].sort(
+        key=lambda item: int(re.search(r"_frame_(\d+)\.jpg$", item["frame"]).group(1))
+    )
     return json_data
 
 def extract_text_from_image(image_path: str) -> str:
