@@ -13,12 +13,21 @@ def transcribe_all_video_paths(directory=None,
                                remove_phrases=None,
                                summarizer=None,
                                kw_model=None,
+                               generator=None,
+                               LEDTokenizer=None,
+                               LEDForConditionalGeneration=None,
                                uploader=None,
                                domain=None,
                                categories=None,
                                videos_url=None,
+                               repository_dir=None,
+                               directory_links=None,
+                               videos_dir=None,
+                               infos_dir=None,
+                               base_url=None,
                                chunk_length_ms=None,
                                chunk_length_diff=None,
+                               title=None,
                                renew=None,
                                remove_text=None,
                                video_id=None):
@@ -34,12 +43,21 @@ def transcribe_all_video_paths(directory=None,
                               remove_phrases=remove_phrases,
                               summarizer=summarizer,
                               kw_model=kw_model,
+                              generator=generator,
+                              LEDTokenizer=LEDTokenizer,
+                              LEDForConditionalGeneration=LEDForConditionalGeneration,
                               uploader=uploader,
                               domain=domain,
                               categories=categories,
                               videos_url=videos_url,
+                              repository_dir=repository_dir,
+                              directory_links=directory_links,
+                              videos_dir=videos_dir,
+                              infos_dir=infos_dir,
+                              base_url=base_url,
                               chunk_length_ms=chunk_length_ms,
                               chunk_length_diff=chunk_length_diff,
+                              title = title,
                               renew=renew,
                               remove_text=remove_text,
                               video_id=video_id)
@@ -50,12 +68,21 @@ def transcribe_video_path(video_path,
                           remove_phrases=None,
                           summarizer=None,
                           kw_model=None,
+                          generator=None,
+                          LEDTokenizer=None,
+                          LEDForConditionalGeneration=None,
                           uploader=None,
                           domain=None,
                           categories=None,
                           videos_url=None,
+                          repository_dir=None,
+                          directory_links=None,
+                          videos_dir=None,
+                          infos_dir=None,
+                          base_url=None,
                           chunk_length_ms=None,
                           chunk_length_diff=None,
+                          title=None,
                           renew=None,
                           remove_text=None,
                           video_id=None):
@@ -71,33 +98,43 @@ def transcribe_video_path(video_path,
                          videos_url=videos_url,
                          chunk_length_ms=chunk_length_ms,
                          chunk_length_diff=chunk_length_diff,
+                         title=title,
                          renew=renew,
                          video_id=video_id)
     
     if not os.path.isfile(info['audio_path']):
         extract_audio_from_video(video_path=info['video_path'],
                                  audio_path=info['audio_path'])
-    
-    info = transcribe_with_whisper_local(
-                                        json_data=info,
-                                        audio_path=info['audio_path'],
-                                        model_size= "small",           # one of "tiny", "base", "small", "medium", "large"
-                                        language='english'
-                                        )
+    if info.get("whisper_result") == None:
+        info = transcribe_with_whisper_local(
+                                            json_data=info,
+                                            audio_path=info['audio_path'],
+                                            model_size= "small",           # one of "tiny", "base", "small", "medium", "large"
+                                            language='english'
+                                            )
     info = analyze_video_text(video_path=info['video_path'],
                        output_dir=info['thumbnails_directory'],
                        json_data=info,
                        remove_phrases=info['remove_phrases'],
                               video_id=info['video_id'])
-    
-    info = get_text_and_keywords(info,
-                                 summarizer=summarizer,
-                                 kw_model=kw_model)
-    info = get_seo_data(info,
-                        uploader=uploader,
-                        domain=domain,
-                        categories=categories,
-                        videos_url=videos_url)
+    if info.get("combined_keywords") == None:
+        info = get_text_and_keywords(info,
+                                     summarizer=summarizer,
+                                     kw_model=kw_model)
+    if info.get('seo_description') == None:
+        info = get_seo_data(info,
+                            uploader=uploader,
+                            domain=domain,
+                            categories=categories,
+                            videos_url=videos_url,
+                            repository_dir=repository_dir,
+                            directory_links=directory_links,
+                            videos_dir=videos_dir,
+                            infos_dir=infos_dir,
+                            base_url=base_url,
+                            generator=generator,
+                            LEDTokenizer=LEDTokenizer,
+                            LEDForConditionalGeneration=LEDForConditionalGeneration)
     safe_dump_to_file(data=info,
                       file_path=info['info_path'])
     return info
@@ -111,6 +148,7 @@ def get_info_data(video_path,
                   videos_url=None,
                   chunk_length_ms=None,
                   chunk_length_diff=None,
+                  title=None,
                   renew=None,
                   remove_text=None,
                   video_id=None):
@@ -136,10 +174,6 @@ def get_info_data(video_path,
     info = {}
     if os.path.isfile(info_path):
         info = safe_read_from_json(info_path)
-        prior_chunk_length = info.get('chunk_length_ms')
-        video_text = info.get('video_text')
-        if prior_chunk_length and remove_text and  chunk_length_ms != prior_chunk_length and video_text != None:
-            del info['video_text']
     
     info['parent_dir']=output_dir
     info['video_path'] = video_path
@@ -148,6 +182,7 @@ def get_info_data(video_path,
     info['info_path'] = info_path
     info['filename'] = video_id
     info['ext'] = ext
+    info['title'] = title
     info['remove_phrases'] = remove_phrases
     info['audio_path'] = audio_path
     info['video_json'] = video_json_path
